//
// Public header file for the Printer Application Framework
//
// Copyright © 2019-2022 by Michael R Sweet.
//
// Licensed under Apache License v2.0.  See the file "LICENSE" for more
// information.
//

#ifndef _PAPPL_PAPPL_H_
#  define _PAPPL_PAPPL_H_
#  include "device.h"
#  include "system.h"
#  include "client.h"
#  include "printer.h"
#  include "job.h"
#  include "loc.h"
#  include "log.h"
#  include "mainloop.h"
#endif // !_PAPPL_PAPPL_H_
